==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ResponsiveStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteringEventArgsDescriptionMetadata } from "./ResponsiveStateEnteringEventArgsDescriptionMetadata";
import { ResponsiveStateEnteredEventArgsDescriptionMetadata } from "./ResponsiveStateEnteredEventArgsDescriptionMetadata";
import { ResponsiveStateExitedEventArgsDescriptionMetadata } from "./ResponsiveStateExitedEventArgsDescriptionMetadata";
import { ResponsiveStateDescription } from "./ResponsiveStateDescription";
/**
 * @hidden
 */
var ResponsiveStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ResponsiveStateDescriptionMetadata, _super);
    function ResponsiveStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateDescriptionMetadata.b = function (a) {
        if (ResponsiveStateDescriptionMetadata.a == null) {
            ResponsiveStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateDescriptionMetadata.c(ResponsiveStateDescriptionMetadata.a);
        }
        if (a.k(ResponsiveStateDescriptionMetadata.a)) {
            return;
        }
        a.ab(ResponsiveStateDescriptionMetadata.a);
        ResponsiveStateEnteringEventArgsDescriptionMetadata.d(a);
        ResponsiveStateEnteredEventArgsDescriptionMetadata.d(a);
        ResponsiveStateExitedEventArgsDescriptionMetadata.d(a);
    };
    ResponsiveStateDescriptionMetadata.c = function (a) {
        a.item("Name", "String");
        a.item("MinimumWidth", "Number:double");
        a.item("MaximumWidth", "Number:double");
        a.item("IsManualState", "Boolean");
        a.item("StateEnteringRef", "EventRef::stateEntering");
        a.item("StateEnteredRef", "EventRef::stateEntered");
        a.item("StateExitedRef", "EventRef::stateExited");
    };
    ResponsiveStateDescriptionMetadata.d = function (a) {
        ResponsiveStateDescriptionMetadata.b(a);
        a.ad("ResponsiveState", function () { return new ResponsiveStateDescription(); });
        a.ac("ResponsiveState", ResponsiveStateDescriptionMetadata.a);
    };
    ResponsiveStateDescriptionMetadata.$t = markType(ResponsiveStateDescriptionMetadata, 'ResponsiveStateDescriptionMetadata');
    ResponsiveStateDescriptionMetadata.a = null;
    return ResponsiveStateDescriptionMetadata;
}(Base));
export { ResponsiveStateDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/ResponsiveStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteringEventArgsDescriptionMetadata } from "./ResponsiveStateEnteringEventArgsDescriptionMetadata";
import { ResponsiveStateEnteredEventArgsDescriptionMetadata } from "./ResponsiveStateEnteredEventArgsDescriptionMetadata";
import { ResponsiveStateExitedEventArgsDescriptionMetadata } from "./ResponsiveStateExitedEventArgsDescriptionMetadata";
import { ResponsiveStateDescription } from "./ResponsiveStateDescription";
/**
 * @hidden
 */
var ResponsiveStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ResponsiveStateDescriptionMetadata, _super);
    function ResponsiveStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateDescriptionMetadata.b = function (a) {
        if (ResponsiveStateDescriptionMetadata.a == null) {
            ResponsiveStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateDescriptionMetadata.c(ResponsiveStateDescriptionMetadata.a);
        }
        if (a.k(ResponsiveStateDescriptionMetadata.a)) {
            return;
        }
        a.ac(ResponsiveStateDescriptionMetadata.a);
        ResponsiveStateEnteringEventArgsDescriptionMetadata.d(a);
        ResponsiveStateEnteredEventArgsDescriptionMetadata.d(a);
        ResponsiveStateExitedEventArgsDescriptionMetadata.d(a);
    };
    ResponsiveStateDescriptionMetadata.c = function (a) {
        a.item("Name", "String");
        a.item("MinimumWidth", "Number:double");
        a.item("MaximumWidth", "Number:double");
        a.item("IsManualState", "Boolean");
        a.item("StateEnteringRef", "EventRef::stateEntering");
        a.item("StateEnteredRef", "EventRef::stateEntered");
        a.item("StateExitedRef", "EventRef::stateExited");
    };
    ResponsiveStateDescriptionMetadata.d = function (a) {
        ResponsiveStateDescriptionMetadata.b(a);
        a.ae("ResponsiveState", function () { return new ResponsiveStateDescription(); });
        a.ad("ResponsiveState", ResponsiveStateDescriptionMetadata.a);
    };
    ResponsiveStateDescriptionMetadata.$t = markType(ResponsiveStateDescriptionMetadata, 'ResponsiveStateDescriptionMetadata');
    ResponsiveStateDescriptionMetadata.a = null;
    return ResponsiveStateDescriptionMetadata;
}(Base));
export { ResponsiveStateDescriptionMetadata };
